==> eBUS_SDK_JAI_Ubuntu-18.04-x86_64-6.5.1-6797.deb.zip: opt/jai/ebus_sdk/Ubuntu-18.04-x86_64/share/doc/sdk/menudata.js <==
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_0x7e.html#index_0x7e"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"z",url:"functions_func_z.html#index_z"},
{text:"~",url:"functions_func_0x7e.html#index_0x7e"}]},
{text:"Enumerations",url:"functions_enum.html"},
{text:"Enumerator",url:"functions_eval.html",children:[
{text:"a",url:"functions_eval.html#index_a"},
{text:"b",url:"functions_eval.html#index_b"},
{text:"c",url:"functions_eval.html#index_c"},
{text:"e",url:"functions_eval.html#index_e"},
{text:"f",url:"functions_eval.html#index_f"},
{text:"g",url:"functions_eval.html#index_g"},
{text:"i",url:"functions_eval.html#index_i"},
{text:"m",url:"functions_eval.html#index_m"},
{text:"n",url:"functions_eval.html#index_n"},
{text:"o",url:"functions_eval.html#index_o"},
{text:"p",url:"functions_eval.html#index_p"},
{text:"r",url:"functions_eval.html#index_r"},
{text:"s",url:"functions_eval.html#index_s"},
{text:"t",url:"functions_eval.html#index_t"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"a",url:"globals.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"g",url:"globals_g.html#index_g"},
{text:"i",url:"globals_i.html#index_i"},
{text:"p",url:"globals_p.html#index_p"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"}]},
{text:"Functions",url:"globals_func.html"},
{text:"Enumerations",url:"globals_enum.html"},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"a",url:"globals_eval.html#index_a"},
{text:"b",url:"globals_eval_b.html#index_b"},
{text:"d",url:"globals_eval_d.html#index_d"},
{text:"e",url:"globals_eval_e.html#index_e"},
{text:"g",url:"globals_eval_g.html#index_g"},
{text:"i",url:"globals_eval_i.html#index_i"},
{text:"p",url:"globals_eval_p.html#index_p"},
{text:"t",url:"globals_eval_t.html#index_t"},
{text:"u",url:"globals_eval_u.html#index_u"}]}]}]}]}

==> eBUS_SDK_JAI_Ubuntu-20.04-x86_64-6.5.1-6797.deb.zip: opt/jai/ebus_sdk/Ubuntu-20.04-x86_64/share/doc/sdk/menudata.js <==
/*
@licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2019 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"q",url:"functions_q.html#index_q"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"z",url:"functions_z.html#index_z"},
{text:"~",url:"functions_~.html#index__7E"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"q",url:"functions_func_q.html#index_q"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"z",url:"functions_func_z.html#index_z"},
{text:"~",url:"functions_func_~.html#index__7E"}]},
{text:"Enumerations",url:"functions_enum.html"},
{text:"Enumerator",url:"functions_eval.html",children:[
{text:"a",url:"functions_eval.html#index_a"},
{text:"b",url:"functions_eval.html#index_b"},
{text:"c",url:"functions_eval.html#index_c"},
{text:"e",url:"functions_eval.html#index_e"},
{text:"f",url:"functions_eval.html#index_f"},
{text:"g",url:"functions_eval.html#index_g"},
{text:"i",url:"functions_eval.html#index_i"},
{text:"m",url:"functions_eval.html#index_m"},
{text:"n",url:"functions_eval.html#index_n"},
{text:"o",url:"functions_eval.html#index_o"},
{text:"p",url:"functions_eval.html#index_p"},
{text:"r",url:"functions_eval.html#index_r"},
{text:"s",url:"functions_eval.html#index_s"},
{text:"t",url:"functions_eval.html#index_t"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"a",url:"globals.html#index_a"},
{text:"b",url:"globals_b.html#index_b"},
{text:"d",url:"globals_d.html#index_d"},
{text:"e",url:"globals_e.html#index_e"},
{text:"g",url:"globals_g.html#index_g"},
{text:"i",url:"globals_i.html#index_i"},
{text:"p",url:"globals_p.html#index_p"},
{text:"t",url:"globals_t.html#index_t"},
{text:"u",url:"globals_u.html#index_u"}]},
{text:"Functions",url:"globals_func.html"},
{text:"Enumerations",url:"globals_enum.html"},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"a",url:"globals_eval.html#index_a"},
{text:"b",url:"globals_eval_b.html#index_b"},
{text:"d",url:"globals_eval_d.html#index_d"},
{text:"e",url:"globals_eval_e.html#index_e"},
{text:"g",url:"globals_eval_g.html#index_g"},
{text:"i",url:"globals_eval_i.html#index_i"},
{text:"p",url:"globals_eval_p.html#index_p"},
{text:"t",url:"globals_eval_t.html#index_t"},
{text:"u",url:"globals_eval_u.html#index_u"}]}]}]}]}
